@@ -3,7 +3,7 @@
 #  Date:           9-Nov-2020 jdw
 #
 #  Updated:
-#
+#   9-Feb-2023 aae  Update ChEMBL baseVersion to 31
 ##
 """
 Accessors for ChEMBL target activity data.
@@ -126,7 +126,7 @@ class ChEMBLTargetActivityProvider(StashableBase):
         super(ChEMBLTargetActivityProvider, self).__init__(self.__cachePath, [self.__dirName])
         self.__dirPath = os.path.join(self.__cachePath, self.__dirName)
         self.__mU = MarshalUtil(workPath=self.__cachePath)
-        baseVersion = 28
+        baseVersion = 31
         self.__version = baseVersion
         logger.info("ChEMBL API MAX_LIMIT %r", Settings.Instance().MAX_LIMIT)  # pylint: disable=no-member
         self.__aD, self.__allIdD = self.__reload(self.__dirPath, useCache)
@@ -302,6 +302,7 @@ class ChEMBLTargetActivityProvider(StashableBase):
 
     def getStatusDetails(self):
         try:
+            version = releaseDateString = None
             baseUrl = "https://www.ebi.ac.uk"
             endPoint = "chembl/api/data/status.json"
             hL = []
@@ -309,9 +310,10 @@ class ChEMBLTargetActivityProvider(StashableBase):
             ureq = UrlRequestUtil()
             ret, retCode = ureq.get(baseUrl, endPoint, pD, headers=hL, returnContentType="JSON")
             logger.info("retCode %r ret %r", retCode, ret)
-            tS = ret["chembl_db_version"] if "chembl_db_version" in ret else None
-            version = tS.split("_")[1] if tS and tS.split("_")[1] else None
-            releaseDateString = ret["chembl_release_date"] if "chembl_release_date" in ret else None
+            if ret:
+                tS = ret["chembl_db_version"] if ret and "chembl_db_version" in ret else None
+                version = tS.split("_")[1] if tS and tS.split("_")[1] else None
+                releaseDateString = ret["chembl_release_date"] if "chembl_release_date" in ret else None
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return version, releaseDateString
